
.. blogpost::
    :title: Pycrypto on Python 3.5
    :keywords: install, pycrypto
    :date: 2015-11-25
    :categories: install, module, windows

    Fortunately, somebody already did that
    and it is available here:
    `sfbahr/PyCrypto-Wheels <https://github.com/sfbahr/PyCrypto-Wheels>`_.
